@@ -93,12 +93,10 @@ sized_render (GKB * gkb)
   Prop *actdata;
   int i = 0;
 
-  gtk_drawing_area_size (GTK_DRAWING_AREA (gkb->darea), gkb->w, gkb->h);
-  gtk_widget_set_usize (GTK_WIDGET (gkb->darea), gkb->w, gkb->h);
-  gtk_widget_set_usize (GTK_WIDGET (gkb->frame), gkb->w, gkb->h);
-  gtk_widget_set_usize (GTK_WIDGET (gkb->applet), gkb->w, gkb->h);
+  if(gkb->small) 
+     gkb->size = applet_widget_get_panel_pixel_size (APPLET_WIDGET (gkb->applet)) / 2;
 
-  if (gkb->orient == ORIENT_UP)
+  if (gkb->orient == ORIENT_UP || gkb->orient ==  ORIENT_DOWN )
     {
       gkb->h = gkb->size;
       gkb->w = gkb->h * 1.5;
@@ -109,6 +107,12 @@ sized_render (GKB * gkb)
       gkb->h = (int) gkb->w / 1.5;
     }
 
+  gtk_drawing_area_size (GTK_DRAWING_AREA (gkb->darea), gkb->w, gkb->h);
+  gtk_widget_set_usize (GTK_WIDGET (gkb->darea), gkb->w, gkb->h);
+  gtk_widget_set_usize (GTK_WIDGET (gkb->frame), gkb->w, gkb->h);
+  gtk_widget_set_usize (GTK_WIDGET (gkb->applet), gkb->w, gkb->h);
+
+
   gtk_widget_queue_resize (gkb->darea);
   gtk_widget_queue_resize (gkb->darea->parent);
   gtk_widget_queue_resize (gkb->darea->parent->parent);
@@ -158,10 +162,14 @@ loadprop (GKB * gkb, int i)
 
   actdata->pix = NULL;
   gkb->orient = applet_widget_get_panel_orient (APPLET_WIDGET (gkb->applet));
-  gkb->size =
-    applet_widget_get_panel_pixel_size (APPLET_WIDGET (gkb->applet));
 
-  if (gkb->orient == ORIENT_UP)
+  if(gkb->small)
+     gkb->size = applet_widget_get_panel_pixel_size (APPLET_WIDGET (gkb->applet)) / 2;
+    else
+     gkb->size =
+       applet_widget_get_panel_pixel_size (APPLET_WIDGET (gkb->applet));
+
+  if (gkb->orient == ORIENT_UP || gkb->orient == ORIENT_DOWN )
     {
       gkb->h = gkb->size;
       gkb->w = gkb->h * 1.5;
@@ -192,6 +200,8 @@ load_properties (GKB * gkb)
 
   gkb->n = gnome_config_get_int ("gkb/num=0");
 
+  gkb->small = gnome_config_get_int ("gkb/small=0");
+
   if (gkb->n == 0)
     {
       actdata = loadprop (gkb, 0);
@@ -261,24 +271,49 @@ gkb_expose (GtkWidget * darea, GdkEventExpose * event, GKB * gkb)
   return FALSE;
 }
 
+static void
+switch_normal(AppletWidget * applet, gpointer gkbx)
+{
+ GKB *gkb = (GKB *) gkbx;
+
+ gkb->small = 0; 
+ gkb->size =
+    applet_widget_get_panel_pixel_size (APPLET_WIDGET (gkb->applet));
+ sized_render (gkb);
+ gkb_draw (gkb);
+}
+
+static void
+switch_small(AppletWidget * applet, gpointer gkbx)
+{
+ GKB *gkb = (GKB *) gkbx;
+
+ gkb->small = 1;
+  sized_render (gkb);
+  gkb_draw (gkb);
+ 
+}
+
 static void
 create_gkb_widget (GKB * gkb)
 {
   GtkStyle *style;
 
-  gtk_widget_push_visual (gdk_imlib_get_visual ());
-  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+  gtk_widget_push_visual (gdk_rgb_get_visual ());
+  gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+         
   style = gtk_widget_get_style (gkb->applet);
 
   gkb->darea = gtk_drawing_area_new ();
+
   gtk_drawing_area_size (GTK_DRAWING_AREA (gkb->darea), gkb->w, gkb->h);
+
   gtk_widget_set_events (gkb->darea,
 			 gtk_widget_get_events (gkb->darea) |
 			 GDK_BUTTON_PRESS_MASK);
 
   gtk_widget_show (gkb->darea);
 
-
   gtk_signal_connect (GTK_OBJECT (gkb->darea), "button_press_event",
 		      GTK_SIGNAL_FUNC (gkb_button_press_event_cb), gkb);
   gtk_signal_connect (GTK_OBJECT (gkb->darea), "expose_event",
@@ -322,7 +357,7 @@ about_cb (AppletWidget * widget, gpointer gkbx)
 			     "Thanks for Balazs Nagy (Kevin) "
 			     "<julian7@kva.hu> for his help "
 			     "and Emese Kovacs <emese@eik.bme.hu> for "
-			     "her solidarity."), "gkb.png");
+			     "her solidarity."), "gkb-icon.png");
 
   link = gnome_href_new ("http://projects.gnome.hu/gkb",
 			 _("GKB Home Page (http://projects.gnome.hu/gkb)"));
@@ -355,6 +390,7 @@ applet_save_session (GtkWidget * w,
 
   gnome_config_push_prefix (privcfgpath);
   gnome_config_set_int ("gkb/num", gkb->n);
+  gnome_config_set_int ("gkb/small", gkb->small);
 
   while (list)
     {
@@ -434,6 +470,23 @@ gkb_activator (PortableServer_POA poa,
 					 _("Properties..."),
 					 properties_dialog, gkb);
 
+ applet_widget_register_callback_dir( APPLET_WIDGET(gkb->applet),
+                                      "size",
+                                      "Size"
+                                       );
+
+ applet_widget_register_stock_callback (APPLET_WIDGET (gkb->applet),
+					 "size/normal",
+					 GNOME_STOCK_MENU_UP,
+					 _("Normal"),
+					 switch_normal, gkb);
+
+ applet_widget_register_stock_callback (APPLET_WIDGET (gkb->applet),
+					 "size/small",
+					 GNOME_STOCK_MENU_DOWN,
+					 _("Small"),
+					 switch_small, gkb);
+
   applet_widget_register_stock_callback (APPLET_WIDGET (gkb->applet),
 					 "help",
 					 GNOME_STOCK_MENU_BOOK_OPEN,
