@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.20 2000/04/18 04:38:20 dmueth Exp $ */
+/* $Id: gweather-applet.c,v 1.21 2000/05/04 12:23:58 jberkman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -20,6 +20,7 @@
 
 #include <gnome.h>
 #include <applet-widget.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include "weather.h"
 #include "gweather-about.h"
@@ -174,6 +175,7 @@ void gweather_applet_create (int argc, char *argv[])
 
     applet_widget_init("gweather", VERSION, argc, argv,
                        NULL, 0, NULL);
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gweather/tstorm.xpm");
 
     if ((gweather_applet = applet_widget_new("gweather")) == NULL)
         g_error(_("Cannot create applet!\n"));
