@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.15 2000/03/14 23:37:33 spapadim Exp $ */
+/* $Id: weather.c,v 1.17 2000/06/01 20:57:19 jleach Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -410,13 +410,13 @@ static gboolean metar_tok_wind (gchar *tokp, WeatherInfo *info)
     sdir[3] = 0;
     dir = (!strcmp(sdir, "VRB")) ? -1 : atoi(sdir);
 
-    bzero(sspd, sizeof(sspd));
+    memset(sspd, 0, sizeof(sspd));
     strncpy(sspd, tokp+3, strspn(tokp+3, CONST_DIGITS));
     spd = atoi(sspd);
 
     gustp = strchr(tokp, 'G');
     if (gustp) {
-        bzero(sgust, sizeof(sgust));
+        memset(sgust, 0, sizeof(sgust));
         strncpy(sgust, gustp+1, strspn(gustp+1, CONST_DIGITS));
         gust = atoi(sgust);
     }
@@ -470,7 +470,7 @@ static gboolean metar_tok_vis (gchar *tokp, WeatherInfo *info)
 
     pfrac = strchr(tokp, '/');
     pend = strstr(tokp, "SM");
-    bzero(sval, sizeof(sval));
+    memset(sval, 0, sizeof(sval));
 
     if (pfrac) {
         strncpy(sval, pfrac + 1, pend - pfrac - 1);
@@ -602,11 +602,11 @@ static gboolean metar_tok_cond (gchar *tokp, WeatherInfo *info)
     else
         pphen = tokp + 2;
 
-    bzero(squal, sizeof(squal));
+    memset(squal, 0, sizeof(squal));
     strncpy(squal, tokp, pphen - tokp);
     squal[pphen - tokp] = 0;
 
-    bzero(sphen, sizeof(sphen));
+    memset(sphen, 0, sizeof(sphen));
     strcpy(sphen, pphen);
 
     /* Defaults */
@@ -1509,6 +1509,8 @@ void _weather_info_get_pixmap (WeatherInfo *info, gboolean mini, GdkPixmap **pix
             switch (cond.qualifier) {
             case QUALIFIER_NONE:
                 break;
+	    case QUALIFIER_VICINITY:
+		break;
             case QUALIFIER_THUNDERSTORM:
                 idx = PIX_TSTORM;
                 break;
@@ -1543,6 +1545,7 @@ void _weather_info_get_pixmap (WeatherInfo *info, gboolean mini, GdkPixmap **pix
                 case PHENOMENON_SNOW:
 		case PHENOMENON_SNOW_GRAINS:
                 case PHENOMENON_ICE_PELLETS:
+		case PHENOMENON_ICE_CRYSTALS:
                     idx = PIX_SNOW;
                     break;
                 case PHENOMENON_HAIL:
