@@ -1,13 +1,11 @@
 /* From wmload.c, v0.9.2, licensed under the GPL. */
+#include <config.h>
 #include <sys/types.h>
 #include <math.h>
 #include <fcntl.h>
 #include <unistd.h>
-
 #include <assert.h>
 
-#include <config.h>
-
 #include <glibtop.h>
 #include <glibtop/cpu.h>
 #include <glibtop/mem.h>
@@ -172,8 +170,9 @@ GetNet (int Maximum, int data [4], LoadGraph *g)
 #define SLIP_COUNT	0
 #define PPP_COUNT	1
 #define ETH_COUNT       2
-#define OTHER_COUNT	3
-#define COUNT_TYPES	4
+#define WVLAN_COUNT     3
+#define OTHER_COUNT	4
+#define COUNT_TYPES	5
     int fields[4], present[COUNT_TYPES], delta[COUNT_TYPES], i;
     static int ticks, past[COUNT_TYPES];
     static char *netdevfmt;
@@ -249,6 +248,9 @@ GetNet (int Maximum, int data [4], LoadGraph *g)
 		if (!strncmp (cp+1, "th", 2))
 			resp = present + ETH_COUNT;
 		break;
+	case 'w':
+		if (!strncmp (cp+1, "vlan", 4))
+			resp = present + WVLAN_COUNT;
 	}
 
 	if ((cp = strchr(buffer, ':')))
