@@ -37,7 +37,7 @@ static const gchar *swap_texts [2] = {
 };
 
 static const gchar *net_texts [4] = {
-    N_("SLIP"), N_("PPP"), N_("ETH"), N_("Other"),
+    N_("SLIP"), N_("PPP"), N_("ETH"), N_("WVLAN"), N_("Other"),
 };
 
 static const gchar *loadavg_texts [2] = {
@@ -58,9 +58,10 @@ static const gchar *swap_color_defs [4] = {
     "#cfff5fff5fff", "#00008fff0000"
 };
 
-static const gchar *net_color_defs [4] = {
+static const gchar *net_color_defs [5] = {
     "#64009500e0e0", "#d300d300d300", 
-    "#00008fff0000", "#ffffffff4fff"
+    "#00008fff0000", "#ffffffff4fff",
+    "#9573f121ffff"
 };
 
 static const gchar *loadavg_color_defs [2] = {
@@ -176,7 +177,7 @@ main (int argc, char **argv)
 #ifdef ENABLE_NLS
     {
         int i;
-        for (i=0;i<3;i++) net_texts[i]=_(net_texts[i]);
+        for (i=0;i<5;i++) net_texts[i]=_(net_texts[i]);
     }
 #endif
     multiload_properties.netload.texts = net_texts;
